diff core/RTAudio.cpp @ 56:3c3a1357657d newapi

Further API update to name three primary functions setup(), render() and cleanup(). Changed include paths so now can #include <BeagleRT.h>. Removed stale pru_rtaudio.bin file as this is now done as pru_rtaudio_bin.h. Updated examples to new API and fixed minor compiler warnings along the way. Network example needs further attention to compile.
author andrewm
date Wed, 15 Jul 2015 12:10:51 +0100
parents be427da6fb9c
children f944d0b60fa8
line wrap: on
line diff
--- a/core/RTAudio.cpp	Mon Jun 15 18:16:00 2015 +0100
+++ b/core/RTAudio.cpp	Wed Jul 15 12:10:51 2015 +0100
@@ -82,7 +82,7 @@
 // plus any latency inherent in the ADCs and DACs themselves.
 // useAnalog indicates whether to enable the ADC and DAC or just use the audio codec.
 // numAnalogChannels indicates how many ADC and DAC channels to use.
 // userData is an opaque pointer which will be passed through to the initialise_render()
 // function for application-specific use
 //
 // Returns 0 on success.
@@ -218,7 +218,7 @@
 	BeagleRT_setHeadphoneLevel(settings->headphoneLevel);
 
 	// Call the user-defined initialisation function
-	if(!initialise_render(&gContext, userData)) {
+	if(!setup(&gContext, userData)) {
 		cout << "Couldn't initialise audio rendering\n";
 		return 1;
 	}
@@ -403,7 +403,7 @@
 // Free any resources associated with PRU real-time audio
 void BeagleRT_cleanupAudio()
 {
-	cleanup_render(&gContext, gUserData);
+	cleanup(&gContext, gUserData);
 
 	// Clean up the auxiliary tasks
 	vector<InternalAuxiliaryTask*>::iterator it;
@@ -82,7 +82,7 @@
 // useAnalog indicates whether to enable the ADC and DAC or just use the audio codec.
 // numAnalogChannels indicates how many ADC and DAC channels to use.
-// userData is an opaque pointer which will be passed through to the initialise_render()
+// userData is an opaque pointer which will be passed through to the setup()
 // function for application-specific use
 //